@@ -29,13 +29,14 @@ class moudle_installer(QtWidgets.QMainWindow,py_inst):
         super(moudle_installer,self).__init__()
         self.setupUi(self)
         self.pushButton.clicked.connect(self.install)
+        self.pushButton_2.clicked.connect(self.uninstall)
 
 
     def install(self):
-        text = ''
-        for i in install(self.lineEdit.text()):
-            text += i
-        self.textBrowser.setText(text)
+
+        install(self.lineEdit.text())
+    def uninstall(self):
+        uninstall(self.lineEdit.text())
 
 
 
@@ -49,27 +50,14 @@ class PS(QtWidgets.QMainWindow,Python_script):
     def runs(self):
         self.un.emit()
     def run_script(self):
-        try:
-            s = self.textEdit.toPlainText()
-            with open('test.py','w') as f:
-                f.write(s)
-            tex = ''
 
-            for i in self.os_popen(f'{sys.executable} test.py'):
-                tex += i
-            if tex:
-                self.textBrowser.setText(tex)
-            else:
-                self.textBrowser.setText('It is Empty!Is Exception happened?Please look of cmd or Idle output.')
-        except BaseException as e:
-            print(e,sys.executable)
-    def os_popen(self,strt):
-        try:
-            self.textBrowser.setText('')
-            re = os.popen(strt).readlines()
-            return re
-        except BaseException as e:
-            print(e)
+        s = self.textEdit.toPlainText()
+        with open('test.py','w') as f:
+            f.write(s)
+        with open('run.bat','w') as f:
+            f.write('@echo off\n'+f'{sys.executable} test.py')
+        subprocess.call('run.bat')
+
 class Fast(QtWidgets.QMainWindow,Fast_link):
     a = pyqtSignal()
     b = pyqtSignal()
